@@ -14,7 +14,9 @@ class StubGenerator(object):
                   type: "GET",
                   url: "/interactive/{{ subview_name }}/html/",
                   complete: function(data) {
-                    console.log(data)
+                    if (callback) {
+                        callback(data);
+                    }
                   }
                 });
             }
@@ -57,8 +59,8 @@ class StubGenerator(object):
                 $.ajax({
                   type: "GET",
                   url: "/interactive/{{ subview_name }}/reload/",
-                  complete: function(data) {
-                    console.log(data)
+                  success: function(data) {
+                    $("#"+data.id).html(data.html_string);
                   }
                 });
             }
